@@ -1,6 +1,3 @@
-require(mva)
-require(scompat)
-
 assign("export.point",
 function(point.obj, filename) {
 
