@@ -1,6 +1,6 @@
 # A plot function for the "point" class of objects
 assign("plot.point",
-function (point.obj,a,axes=T,xlab='',ylab='',legend.pos=0,...) {
+function (point.obj,a,axes=T,xlab='',ylab='',legend.pos=0,add=F,...) {
 # Be careful to plot in a square region.  We can't distort the earth!
 # I can't seem to force Splus to use the same scaling on both axes!
 # But we must find a way!
@@ -25,8 +25,10 @@ function (point.obj,a,axes=T,xlab='',ylab='',legend.pos=0,...) {
     a.q<-quantile(a,c(.25,.5,.75,1))	
     qcol<-c(3,7,2,6) # green, yellow, red, cyan
     colors <- cut(a,c(min(a)-1,a.q),labels=c(1:4))
-    plot(point.obj$x,point.obj$y, axes=axes,xlab=xlab,ylab=ylab,type='n',
-         xlim=xlimits,ylim=ylimits)
+    if(!add){
+      plot(point.obj$x,point.obj$y, axes=axes,xlab=xlab,ylab=ylab,type='n',
+           xlim=xlimits,ylim=ylimits)
+    }
     for (i in as.numeric(unique(colors))){
       points(point.obj$x[colors==i],point.obj$y[colors==i],col=qcol[i],...)
 }
@@ -52,9 +54,13 @@ function (point.obj,a,axes=T,xlab='',ylab='',legend.pos=0,...) {
     
   }
   else {
-    plot(point.obj$x,point.obj$y, axes=axes,xlab=xlab,ylab=ylab,
-         xlim=xlimits,ylim=ylimits)
-    title(deparse(substitute(point.obj)))
+    if(!add){
+      plot(point.obj$x,point.obj$y, axes=axes,xlab=xlab,ylab=ylab,
+           xlim=xlimits,ylim=ylimits)
+      title(deparse(substitute(point.obj)))
+    } else {
+      points(point.obj$x,point.obj$y)
+    }
   }
   invisible(par(old.par))
 })
